@@ -79,9 +79,9 @@ RANDOM_HEADERS = True
 # requests 使用session
 USE_SESSION = False
 
-# 过滤
-ITEM_FILTER_ENABLE = False
-REQUEST_FILTER_ENABLE = False
+# 去重
+ITEM_FILTER_ENABLE = False # item 去重
+REQUEST_FILTER_ENABLE = False # request 去重
 
 # 报警
 DINGDING_WARNING_URL = ""
